@@ -1,6 +1,6 @@
 package sdl4gcj.mixer;
 
-import sdl4gcj.Sys;
+import sdl4gcj.SDLSystem;
 import sdl4gcj.SDLConstants;
 
 public interface MixerConstants
@@ -11,8 +11,8 @@ public interface MixerConstants
 	int AUDIO_S16LSB = 0x8010; // Signed 16-bit samples 
 	int AUDIO_U16MSB = 0x1010; // As above, but big-endian byte order 
 	int AUDIO_S16MSB = 0x9010; // As above, but big-endian byte order 
-	int AUDIO_U16    = (Sys.byteOrder() == SDLConstants.SDL_LIL_ENDIAN) ? AUDIO_U16LSB : AUDIO_U16MSB;
-	int AUDIO_S16    = (Sys.byteOrder() == SDLConstants.SDL_LIL_ENDIAN) ? AUDIO_S16LSB : AUDIO_S16MSB;
+	int AUDIO_U16    = (SDLSystem.byteOrder() == SDLConstants.SDL_LIL_ENDIAN) ? AUDIO_U16LSB : AUDIO_U16MSB;
+	int AUDIO_S16    = (SDLSystem.byteOrder() == SDLConstants.SDL_LIL_ENDIAN) ? AUDIO_S16LSB : AUDIO_S16MSB;
 
 	// Mix_Fading
 	int MIX_NO_FADING    = 0;
