@@ -10,17 +10,17 @@ public class Test implements SDLConstants
 
 	public static void main(String[] args)
 	{
-		if (Sys.init(Sys.SDL_INIT_VIDEO) != 0)
+		if (SDLSystem.init(SDL_INIT_VIDEO) != 0)
 		{
 			System.out.println("Init() fail");
 			System.exit(0);
 		}
-		System.out.println(" Compiled SDL Version : " + Sys.compiledVersion());
-		System.out.println("   Linked SDL Version : " + Sys.linkedVersion());
-		if (Sys.byteOrder() == SDL_LIL_ENDIAN)
-			System.out.println("Sys.byteOrder() : SDL_LIL_ENDIAN = " + Sys.byteOrder());
+		System.out.println(" Compiled SDL Version : " + SDLSystem.compiledVersion());
+		System.out.println("   Linked SDL Version : " + SDLSystem.linkedVersion());
+		if (SDLSystem.byteOrder() == SDL_LIL_ENDIAN)
+			System.out.println("SDLSystem.byteOrder() : SDL_LIL_ENDIAN = " + SDLSystem.byteOrder());
 		else
-			System.out.println("Sys.byteOrder() : SDL_BIG_ENDIAN = " + Sys.byteOrder());
+			System.out.println("SDLSystem.byteOrder() : SDL_BIG_ENDIAN = " + SDLSystem.byteOrder());
 
 		try
 		{
@@ -101,7 +101,7 @@ public class Test implements SDLConstants
 		}
 		finally
 		{
-			Sys.quit();
+			SDLSystem.quit();
 		}
 	}
 }
